#!/bin/sh
#
# check_stale_nfs plugin to check for stale NFS file handles or old mounts
#

PROGRAM=`basename $0`

usage() {
 echo "USAGE: check_stale_nfs.sh [<-h> | <-s> | <-o>]"
}

print_help() {
 echo ""
 usage
 echo ""
 echo "This plugin checks for stale NFS file handles or old mounts"
 echo "Option -s (default) checks for stale file handles"
 echo "Option -o checks for old mounts"
}

check="stale"
case "$1" in
 --help)
  print_help
  exit 0
  ;;
 -h)
  print_help
  exit 0
  ;;
 -s)
  check="stale"
  shift
  ;;
 -o)
  check="old"
  shift
  ;;
esac
#
if [ $# -gt 0 ]
then
 echo ""
 echo "Wrong input for check_stale_nfs nagios plugin"
 usage
 exit 3
fi

rc=0
if [ "$check" = "stale" ]
then
# Check for stale NFS file handle
 mess="Stale NFS file handle(s) for"
 for m in `mount -t nfs | awk -F " on" '{print $2}' | awk '{ print $1}'`
 do
  if [ `ls $m 2>&1 | grep "Stale" | wc -l` -gt 0 ]
  then
   mess="$mess $m"
   rc=2
  fi
 done
elif [ "$check" = "old" ]
then
# Check for old NFS filesystems
 mess="Old NFS filesystem(s):"
 for m in `mount -t nfs | awk -F " on" '{print $2}' | awk '{ print $1}'`
 do
  if [ `ls $m/STALE 2>/dev/null | grep "STALE" | wc -l` -gt 0 ]
  then
   mess="$mess $m"
   rc=2
  fi
 done
fi
if [ $rc -eq 0 ]
then
 echo "No $check NFS file handles"
elif [ $rc -eq 2 ]
then
 echo $mess
else
 echo "Problem with $PROGRAM plugin"
 rc=3
fi
exit $rc
